/**
 * Custom element `<skribbl-menu>` for the name selection menu that appears when first entering a game.
 */
export default class SkribblMenu extends HTMLElement {
	constructor(){
		super();
		this.attachShadow({mode:"open"});
		this.shadowRoot.innerHTML = `
			<style>
				:host {
					display: block;
					background: #ffffff;
					border-radius: 10px;
					padding: 15px;
				}
			</style>
			<input type="text">
			<button>Play</button>
		`;
		this._nameInput = this.shadowRoot.querySelector("input");
		this._playButton = this.shadowRoot.querySelector("button");
		/** @type {Promise<{name:string}>} */
		this._proceedPromise = new Promise(resolve=>{
			this._playButton.addEventListener("click",e=>{
				resolve({name:this._nameInput.value});
			});
		});
	}

	/**
	 * Waits until the user clicks play, then returns the name and settings he has chosen.
	 */
	async awaitProceed(){
		return await this._proceedPromise;
	}
}
customElements.define("skribbl-menu",SkribblMenu);